@@ -6,7 +6,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalDownload.py 6100 2017-06-07 15:15:03Z brideout $
+$Id: globalDownload.py 6116 2017-06-21 14:33:21Z brideout $
 """
 
 usage = """
@@ -170,7 +170,7 @@ def getInstrumentList(inst, server):
                     break
             # print warning if none found
             if instFound == 0:
-                print 'Warning: unable to find instrument ' + str(item)
+                print('Warning: unable to find instrument ' + str(item))
         else:
             # use regular expression matching
             instFound = 0
@@ -183,7 +183,7 @@ def getInstrumentList(inst, server):
         
             # print warning if none found
             if instFound == 0:
-                print 'Warning: unable to find instrument ' + str(item)
+                print('Warning: unable to find instrument ' + str(item))
 
     return retList
 
@@ -206,27 +206,27 @@ def filterExperimentsUsingSeason(expList, seasonalStartDate, seasonalEndDate):
     # parse seasonalStartDate and seasonalEndDate
     dateList = seasonalStartDate.split('/')
     if len(dateList) != 2:
-        raise ValueError, 'seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate)
+        raise ValueError('seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate))
     try:
         startmonth = int(dateList[0])
         startday = int(dateList[1])
     except:
-        raise ValueError, 'seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate)
+        raise ValueError('seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate))
 
     if startmonth < 1 or startmonth > 12 or startday < 1 or startday > 31:
-        raise ValueError, 'seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate)
+        raise ValueError('seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate))
 
     dateList = seasonalEndDate.split('/')
     if len(dateList) != 2:
-        raise ValueError, 'seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate)
+        raise ValueError('seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate))
     try:
         endmonth = int(dateList[0])
         endday = int(dateList[1])
     except:
-        raise ValueError, 'seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate)
+        raise ValueError('seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate))
 
     if endmonth < 1 or endmonth > 12 or endday < 1 or endday > 31:
-        raise ValueError, 'seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate)
+        raise ValueError('seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate))
 
     retList = []
 
@@ -498,11 +498,11 @@ def getSubdirectoryFromFullFile(fullFilename):
     dirname = os.path.dirname(fullFilename)
     i = dirname.find('/experiments')
     if i == -1:
-        raise ValueError, 'Illegal filename %s' % (fullFilename)
+        raise ValueError('Illegal filename %s' % (fullFilename))
     dirname = dirname[i+len('/experiments'):]
     i = dirname.find('/')
     if i == -1:
-        raise ValueError, 'Illegal filename %s' % (fullFilename)
+        raise ValueError('Illegal filename %s' % (fullFilename))
     return(dirname[i+1:])
 
 
@@ -553,7 +553,7 @@ fileDesc = None
 
 # check if none passed in
 if len(optlist) == 0:
-    print usage
+    print(usage)
     sys.exit(0)
     
 
@@ -598,40 +598,40 @@ for opt in optlist:
         verbose = 1
 
     else:
-        raise ValueError, 'Illegal option %s\n%s' % (opt[0], usage)
+        raise ValueError('Illegal option %s\n%s' % (opt[0], usage))
     
 # verify that no regular arguments were passed in
 if len(args) != 0:
-    raise ValueError, 'This command does not accept any arguments without options - may be due to illegal spaces in the command'
+    raise ValueError('This command does not accept any arguments without options - may be due to illegal spaces in the command')
 
 # check that all required arguments passed in
 if url == None:
-    print '--url argument required - must be the url of the main page of a Madrigal site'
+    print('--url argument required - must be the url of the main page of a Madrigal site')
     sys.exit(0)
 
 if outputDir == None:
-    print '--outputDir argument required - must be a valid, writable file directory'
+    print('--outputDir argument required - must be a valid, writable file directory')
     sys.exit(0)
 elif not os.access(outputDir, os.W_OK):
     try:
         os.makedirs(outputDir)
     except:
-        raise IOError, 'Unable to either write to or create %s' % (outputDir)
+        raise IOError('Unable to either write to or create %s' % (outputDir))
 
 if user_fullname == None:
-    print '--user_fullname argument required - must your name'
+    print('--user_fullname argument required - must your name')
     sys.exit(0)
 
 if user_email == None:
-    print '--user_email argument required - must your email address'
+    print('--user_email argument required - must your email address')
     sys.exit(0)
 
 if user_affiliation == None:
-    print '--user_affiliation argument required - must your affiliation'
+    print('--user_affiliation argument required - must your affiliation')
     sys.exit(0)
     
 if format not in ('simple', 'hdf5'):
-    print '--format must be given as either ascii or hdf5'
+    print('--format must be given as either ascii or hdf5')
     sys.exit(0)
 
 # set startDate
@@ -642,18 +642,18 @@ if startDate == None:
 else:
     dateList = startDate.split('/')
     if len(dateList) != 3:
-        print '--startDate must be in the form MM/DD/YYYY: ' + str(startDate)
+        print('--startDate must be in the form MM/DD/YYYY: ' + str(startDate))
         sys.exit(0)
     startmonth = int(dateList[0])
     startday = int(dateList[1])
     startyear = int(dateList[2])
     if startmonth < 1 or startmonth > 12 or startday < 1 or startday > 31:
-        print '--startDate must be in the form MM/DD/YYYY: ' + str(startDate)
+        print('--startDate must be in the form MM/DD/YYYY: ' + str(startDate))
         sys.exit(0)
     try:
         datetime.datetime(startyear, startmonth, startday)
     except:
-        print 'Invalid startDate <%s>' % (str(startDate))
+        print('Invalid startDate <%s>' % (str(startDate)))
         sys.exit(0)
 
 # set endDate
@@ -667,18 +667,18 @@ if endDate == None:
 else:
     dateList = endDate.split('/')
     if len(dateList) != 3:
-        print '--endDate must be in the form MM/DD/YYYY: ' + str(endDate)
+        print('--endDate must be in the form MM/DD/YYYY: ' + str(endDate))
         sys.exit(0)
     endmonth = int(dateList[0])
     endday = int(dateList[1])
     endyear = int(dateList[2])
     if endmonth < 1 or endmonth > 12 or endday < 1 or endday > 31:
-        print '--endDate must be in the form MM/DD/YYYY: ' + str(endDate)
+        print('--endDate must be in the form MM/DD/YYYY: ' + str(endDate))
         sys.exit(0)
     try:
         datetime.datetime(endyear, endmonth, endday)
     except:
-        print 'Invalid endDate <%s>' % (str(endDate))
+        print('Invalid endDate <%s>' % (str(endDate)))
         sys.exit(0)
 
 timeList = (startyear, startmonth, startday, 0, 0, 0,
@@ -734,18 +734,18 @@ if fileDesc != None:
 
 # print error if no files selected
 if len(expFileList) == 0:
-    print 'No files selected with these arguments'
+    print('No files selected with these arguments')
     sys.exit(0)
 
 # print message if verbose
 numFiles = len(expFileList)
 if verbose:
-    print "%i files being downloaded" % (numFiles)
+    print("%i files being downloaded" % (numFiles))
 
 # loop through each file to download
 for i in range(numFiles):
     if verbose:
-        print  'Downloading file %i of %i: %s' % (i+1, numFiles, expFileList[i].name)
+        print('Downloading file %i of %i: %s' % (i+1, numFiles, expFileList[i].name))
     if tree:
         subDir = getSubdirectoryFromFullFile(expFileList[i].name)
         saveDir = os.path.join(outputDir, subDir)
@@ -778,5 +778,5 @@ for i in range(numFiles):
                             user_fullname, user_email, user_affiliation,
                             format)
     except socket.timeout:
-        print('Failure downloading %s because it took more than allowed number of seconds' % (expFileList[i].name))
+        print(('Failure downloading %s because it took more than allowed number of seconds' % (expFileList[i].name)))
 
