@@ -5,7 +5,7 @@
     This script is a stand-alone application, and can be run from anywhere with a connection to the internet.
     It runs on either unix or windows.  It requires only the MadrigalWeb python module to be installed.
 
-$Id: globalIsprint.py 5863 2016-10-07 20:11:15Z brideout $
+$Id: globalIsprint.py 6116 2017-06-21 14:33:21Z brideout $
 """
 
 usage = """
@@ -188,7 +188,7 @@ def getInstrumentList(inst, server):
                     break
             # print warning if none found
             if instFound == 0:
-                print 'Warning: unable to find instrument ' + str(item)
+                print('Warning: unable to find instrument ' + str(item))
         else:
             # use regular expression matching
             instFound = 0
@@ -201,7 +201,7 @@ def getInstrumentList(inst, server):
         
             # print warning if none found
             if instFound == 0:
-                print 'Warning: unable to find instrument ' + str(item)
+                print('Warning: unable to find instrument ' + str(item))
 
     return retList
 
@@ -224,27 +224,27 @@ def filterExperimentsUsingSeason(expList, seasonalStartDate, seasonalEndDate):
     # parse seasonalStartDate and seasonalEndDate
     dateList = seasonalStartDate.split('/')
     if len(dateList) != 2:
-        raise ValueError, 'seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate)
+        raise ValueError('seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate))
     try:
         startmonth = int(dateList[0])
         startday = int(dateList[1])
     except:
-        raise ValueError, 'seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate)
+        raise ValueError('seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate))
 
     if startmonth < 1 or startmonth > 12 or startday < 1 or startday > 31:
-        raise ValueError, 'seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate)
+        raise ValueError('seasonalStartDate must be in form MM/DD: ' + str(seasonalStartDate))
 
     dateList = seasonalEndDate.split('/')
     if len(dateList) != 2:
-        raise ValueError, 'seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate)
+        raise ValueError('seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate))
     try:
         endmonth = int(dateList[0])
         endday = int(dateList[1])
     except:
-        raise ValueError, 'seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate)
+        raise ValueError('seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate))
 
     if endmonth < 1 or endmonth > 12 or endday < 1 or endday > 31:
-        raise ValueError, 'seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate)
+        raise ValueError('seasonalEndDate must be in form MM/DD: ' + str(seasonalEndDate))
 
     retList = []
 
@@ -349,7 +349,7 @@ def getExperimentFileList(server, expList, verbose):
 
     for i, exp in enumerate(expList):
         if verbose:
-            print('checking experiment %i of %i' % (i,len(expList)))
+            print(('checking experiment %i of %i' % (i,len(expList))))
         try:
             theseExpFiles = server.getExperimentFiles(exp.id)
         except:
@@ -643,7 +643,7 @@ fileDesc = None
 
 # check if none passed in
 if len(optlist) == 0:
-    print usage
+    print(usage)
     sys.exit(-1)
     
 
@@ -700,57 +700,57 @@ for opt in optlist:
         verbose = 1
 
     else:
-        raise ValueError, 'Illegal option %s\n%s' % (opt[0], usage)
+        raise ValueError('Illegal option %s\n%s' % (opt[0], usage))
     
 # verify that no regular arguments were passed in
 if len(args) != 0:
     print(usage)
-    raise ValueError, 'This command does not accept any arguments without options - may be due to illegal spaces in the command'
+    raise ValueError('This command does not accept any arguments without options - may be due to illegal spaces in the command')
 
 # check that all required arguments passed in
 if url is None:
     print(usage)
-    print '--url argument required - must be the url of the main page of a Madrigal site'
+    print('--url argument required - must be the url of the main page of a Madrigal site')
     sys.exit(-1)
 
 if parms is None:
     print(usage)
-    print '--parms argument required - must be a comma-separated list of Madrigal mnemonics'
+    print('--parms argument required - must be a comma-separated list of Madrigal mnemonics')
     sys.exit(-1)
 
 if output is None:
     print(usage)
-    print '--output argument required - must be a valid, writable file or directory path'
+    print('--output argument required - must be a valid, writable file or directory path')
     sys.exit(-1)
 
 if user_fullname is None:
     print(usage)
-    print '--user_fullname argument required - must your name'
+    print('--user_fullname argument required - must your name')
     sys.exit(-1)
 
 if user_email is None:
     print(usage)
-    print '--user_email argument required - must your email address'
+    print('--user_email argument required - must your email address')
     sys.exit(-1)
 
 if user_affiliation is None:
     print(usage)
-    print '--user_affiliation argument required - must your affiliation'
+    print('--user_affiliation argument required - must your affiliation')
     sys.exit(-1)
     
 if not format is None:
     if format not in ('Hdf5', 'netCDF4', 'ascii'):
         print(usage)
-        print('Format must be in Hdf5, netCDF4, or ascii, not <%s>' % (str(format)))
+        print(('Format must be in Hdf5, netCDF4, or ascii, not <%s>' % (str(format))))
         sys.exit(-1)
     # output must be a writeable directory
     if not os.path.isdir(output):
         print(usage)
-        print('If format set, output <%s> must be a writable directory' % (output))
+        print(('If format set, output <%s> must be a writable directory' % (output)))
     else:
         if not os.access(output, os.W_OK):
             print(usage)
-            print('If format set, output <%s> must be a writable directory' % (output))
+            print(('If format set, output <%s> must be a writable directory' % (output)))
 
 # set startDate
 if startDate is None:
@@ -760,18 +760,18 @@ if startDate is None:
 else:
     dateList = startDate.split('/')
     if len(dateList) != 3:
-        print '--startDate must be in the form MM/DD/YYYY: ' + str(startDate)
+        print('--startDate must be in the form MM/DD/YYYY: ' + str(startDate))
         sys.exit(-1)
     startmonth = int(dateList[0])
     startday = int(dateList[1])
     startyear = int(dateList[2])
     if startmonth < 1 or startmonth > 12 or startday < 1 or startday > 31:
-        print '--startDate must be in the form MM/DD/YYYY: ' + str(startDate)
+        print('--startDate must be in the form MM/DD/YYYY: ' + str(startDate))
         sys.exit(-1)
     try:
         datetime.datetime(startyear, startmonth, startday)
     except:
-        print 'Invalid startDate <%s>' % (str(startDate))
+        print('Invalid startDate <%s>' % (str(startDate)))
         sys.exit(-1)
 
 # set endDate
@@ -785,18 +785,18 @@ if endDate is None:
 else:
     dateList = endDate.split('/')
     if len(dateList) != 3:
-        print '--endDate must be in the form MM/DD/YYYY: ' + str(endDate)
+        print('--endDate must be in the form MM/DD/YYYY: ' + str(endDate))
         sys.exit(-1)
     endmonth = int(dateList[0])
     endday = int(dateList[1])
     endyear = int(dateList[2])
     if endmonth < 1 or endmonth > 12 or endday < 1 or endday > 31:
-        print '--endDate must be in the form MM/DD/YYYY: ' + str(endDate)
+        print('--endDate must be in the form MM/DD/YYYY: ' + str(endDate))
         sys.exit(-1)
     try:
         datetime.datetime(endyear, endmonth, endday)
     except:
-        print 'Invalid endDate <%s>' % (str(endDate))
+        print('Invalid endDate <%s>' % (str(endDate)))
         sys.exit(-1)
 
 timeList = (startyear, startmonth, startday, 0, 0, 0,
@@ -856,7 +856,7 @@ if fileDesc != None:
 
 # print error if no files selected
 if len(expFileList) == 0:
-    print 'No files selected with these arguments'
+    print('No files selected with these arguments')
     sys.exit(-1)
 
 # open output file if needed
@@ -879,7 +879,7 @@ if format is None and not hideParms:
 # print message if verbose
 numFiles = len(expFileList)
 if verbose:
-    print "%i files being analyzed" % (numFiles)
+    print("%i files being analyzed" % (numFiles))
 
 # isprint to output file from each expFileList
 delimiter = ' '
@@ -890,7 +890,7 @@ if filterStr.find('date1') == -1:
     newFilterStr = filterStr + getTimeParms(timeList, 1, 0)
 for i in range(numFiles):
     if verbose:
-        print  'Analyzing file %i of %i: %s' % (i+1, numFiles, expFileList[i].name)
+        print('Analyzing file %i of %i: %s' % (i+1, numFiles, expFileList[i].name))
     if showFiles and (format is None):
         outputFile.write('%s\n' % (expFileList[i].name))
     outputFileArg = getOutputFileArg(expFileList[i].name, format, output)
@@ -949,7 +949,7 @@ for i in range(numFiles):
                     outputFile.write(data[1:]) # skip leading space
                 except:
                     if verbose:
-                        print  'Failure analyzing file %s with slice %s' % (expFileList[i].name, newParms)
+                        print('Failure analyzing file %s with slice %s' % (expFileList[i].name, newParms))
                     continue
         else:
             raise
