@@ -2,7 +2,7 @@
 
 """
 
-# $Id: madrigalWeb.py 6110 2017-06-19 19:40:34Z brideout $
+# $Id: madrigalWeb.py 6277 2017-11-06 19:13:17Z brideout $
 
 
 import os, os.path, sys
@@ -441,7 +441,7 @@ class MadrigalData:
         # check that error was not returned
         for line in page:
             if line.find('Error occurred') != -1:
-                raise ValueError, 'error raised using url ' + str(url) + ' ' + str(page)
+                raise ValueError('error raised using url ' + str(url) + ' ' + str(page))
 
         result = []
 
@@ -978,8 +978,10 @@ class MadrigalData:
                 postUrl += str(twoDParmValues[i][j])
                 if j + 1 < len(twoDParmValues[i]):
                     postUrl += ','
+                    
+        # remove any pluses in the url due to scientific notation
+        postUrl = postUrl.replace('+', '%2B')
             
-        
         data = postUrl.encode("utf-8")
 
         # read main url
@@ -1258,8 +1260,11 @@ class MadrigalData:
                 for k, value in enumerate(valueList):
                     postUrl += '%f' % (value)
                     if j+1 < len(twoDParmValues[i]) or k+1 < len(valueList):
-                        postUrl += ','           
-            
+                        postUrl += ','  
+                        
+        # remove any pluses in the url due to scientific notation
+        postUrl = postUrl.replace('+', '%2B')
+                 
         data = postUrl.encode('utf8')
 
         # read main url
@@ -1411,6 +1416,9 @@ class MadrigalData:
         url += '=%i&stephours' % (int(endsec))
         url += '=%f&parms' % (float(stephours))
         url += '=%s' % (parms)
+        
+        # remove any pluses in the url due to scientific notation
+        url = url.replace('+', '%2B')
 
         # read main url
         try:
@@ -1520,6 +1528,9 @@ class MadrigalData:
             url += 'az=%f&' % (az)
             url += 'el=%f&' % (el)
             url += 'range=%f&' % (radarRange)
+            
+        # remove any pluses in the url due to scientific notation
+        url = url.replace('+', '%2B')
 
         # read main url
         try:
@@ -1627,6 +1638,9 @@ class MadrigalData:
             url += 'gdlat=%f&' % (gdlat)
             url += 'glon=%f&' % (glon)
             url += 'gdalt=%f&' % (gdalt)
+            
+        # remove any pluses in the url due to scientific notation
+        url = url.replace('+', '%2B')
 
         # read main url
         try:
@@ -1915,6 +1929,9 @@ class MadrigalData:
             else:
                 stopAlt = 0.0
         url += 'stopAlt=%s' % (str(stopAlt))
+        
+        # remove any pluses in the url due to scientific notation
+        url = url.replace('+', '%2B')
 
         # read main url
         try:
@@ -2060,19 +2077,22 @@ class MadrigalInstrument:
 
         self.altitude = float(altitude)
         
-        self.category = str(category)
+        if not isStringType(category):
+            raise ValueError('In MadrigalInstrument, category not string type: %s' % (str(category)))
+        
+        self.category = category
         
 
     def __str__(self):
         """return a readible form of this object"""
         retStr = ''
-        retStr += 'name: %s\n' % (str(self.name))
+        retStr += 'name: %s\n' % (self.name)
         retStr += 'code: %s\n' % (str(self.code))
-        retStr += 'mnemonic: %s\n' % (str(self.mnemonic))
+        retStr += 'mnemonic: %s\n' % (self.mnemonic)
         retStr += 'latitude: %s\n' % (str(self.latitude))
         retStr += 'longitude: %s\n' % (str(self.longitude))
         retStr += 'altitude: %s\n'%  (str(self.altitude))
-        retStr += 'category: %s\n'%  (str(self.category))
+        retStr += 'category: %s\n'%  (self.category)
         return retStr
 
 
@@ -2302,9 +2322,15 @@ class MadrigalExperiment:
 
         self.madrigalUrl = madrigalUrl
         
-        self.pi = str(pi)
+        if not isStringType(pi):
+            raise ValueError('In MadrigalExperiment, pi not string type: %s' % (str(pi)))
+
+        self.pi = pi
         
-        self.piEmail = str(piEmail)
+        if not isStringType(piEmail):
+            raise ValueError('In MadrigalExperiment, piEmail not string type: %s' % (str(piEmail)))
+                
+        self.piEmail = piEmail
         
         if self.isLocal:
             self.realUrl = self._getRealExperimentUrl(version)
@@ -2315,6 +2341,8 @@ class MadrigalExperiment:
         
         self.access = access     
         
+        if not isStringType(version):
+            raise ValueError('In MadrigalExperiment, version not string type: %s' % (str(version)))
         self.version = version   
         
 
@@ -2337,7 +2365,7 @@ class MadrigalExperiment:
             try:
                 retStr += urlparse.quote_plus(self.name) # python3
             except AttributeError:
-                retStr += urllib.quote_plus(self.name) # python2
+                retStr += urllib.quote_plus(self.name.encode('utf8')) # python2
         else:
             retStr += self.url[:index] + '/showExperiment/?experiment_list=%i' % (self.id)
         return(retStr)
@@ -2347,13 +2375,13 @@ class MadrigalExperiment:
         """return a readible form of this object"""
         retStr = ''
         retStr += 'id: %s\n' % (str(self.id))
-        retStr += 'realUrl: %s\n' % (str(self.realUrl))
-        retStr += 'url: %s\n' % (str(self.url))
-        retStr += 'name: %s\n' % (str(self.name))
+        retStr += 'realUrl: %s\n' % (self.realUrl)
+        retStr += 'url: %s\n' % (self.url)
+        retStr += 'name: %s\n' % (self.name)
         retStr += 'siteid: %s\n' % (str(self.siteid))
-        retStr += 'sitename: %s\n' % (str(self.sitename))
+        retStr += 'sitename: %s\n' % (self.sitename)
         retStr += 'instcode: %s\n'%  (str(self.instcode))
-        retStr += 'instname: %s\n' % (str(self.instname))
+        retStr += 'instname: %s\n' % (self.instname)
         retStr += 'startyear: %s\n' % (str(self.startyear))
         retStr += 'startmonth: %s\n'%  (str(self.startmonth))
         retStr += 'startday: %s\n' % (str(self.startday))
@@ -2367,12 +2395,12 @@ class MadrigalExperiment:
         retStr += 'endmin: %s\n' % (str(self.endmin))
         retStr += 'endsec: %s\n'%  (str(self.endsec))
         retStr += 'isLocal: %s\n' % (str(self.isLocal))
-        retStr += 'madrigalUrl: %s\n'%  (str(self.madrigalUrl))
-        retStr += 'PI: %s\n'%  (str(self.pi))
-        retStr += 'PIEmail: %s\n'%  (str(self.piEmail))
+        retStr += 'madrigalUrl: %s\n'%  (self.madrigalUrl)
+        retStr += 'PI: %s\n'%  (self.pi)
+        retStr += 'PIEmail: %s\n'%  (self.piEmail)
         retStr += 'uttimestamp: %s\n'%  (str(self.uttimestamp))
         retStr += 'access: %s\n'%  (str(self.access))
-        retStr += 'Madrigal version: %s\n'%  (str(self. version))
+        retStr += 'Madrigal version: %s\n'%  (self. version)
         return retStr
 
     def __cmp__(self, other):
@@ -2393,9 +2421,81 @@ class MadrigalExperiment:
                                 self.endhour, self.endmin, self.endsec)
         dt2 = datetime.datetime(other.endyear, other.endmonth, other.endday,
                                 other.endhour, other.endmin, other.endsec)
-        return(cmp(dt1, dt2))                       
+        return(cmp(dt1, dt2))     
+    
+    
+    def __eq__(self, other):
+        """ __eq__ compares two MadrigalExperiment objects for equality.
+
+        Compared by start time and end time.
+        """
+        dt1s = datetime.datetime(self.startyear, self.startmonth, self.startday,
+                                self.starthour, self.startmin, self.startsec)
+        dt2s = datetime.datetime(other.startyear, other.startmonth, other.startday,
+                                other.starthour, other.startmin, other.startsec)
+
         
+        dt1e = datetime.datetime(self.endyear, self.endmonth, self.endday,
+                                self.endhour, self.endmin, self.endsec)
+        dt2e = datetime.datetime(other.endyear, other.endmonth, other.endday,
+                                other.endhour, other.endmin, other.endsec)
+        return(dt1s == dt2s and dt1e == dt2e)                   
         
+    def __ne__(self, other):
+        """ __ne__ compares two MadrigalExperiment objects for inequality.
+
+        Simply the inverse of __eq__
+        """
+        return(not(self.__eq__(self, other)))
+    
+    
+    def __lt__(self, other):
+        """ __lt__ compares two MadrigalExperiment objects.
+
+        Compared by start time only
+        """
+        dt1 = datetime.datetime(self.startyear, self.startmonth, self.startday,
+                                self.starthour, self.startmin, self.startsec)
+        dt2 = datetime.datetime(other.startyear, other.startmonth, other.startday,
+                                other.starthour, other.startmin, other.startsec)
+        return (dt1 < dt2)
+    
+    def __le__(self, other):
+        """ __le__ compares two MadrigalExperiment objects.
+
+        Compared by start time only
+        """
+        dt1 = datetime.datetime(self.startyear, self.startmonth, self.startday,
+                                self.starthour, self.startmin, self.startsec)
+        dt2 = datetime.datetime(other.startyear, other.startmonth, other.startday,
+                                other.starthour, other.startmin, other.startsec)
+        return (dt1 <= dt2)
+    
+    def __gt__(self, other):
+        """ __gt__ compares two MadrigalExperiment objects.
+
+        Compared by start time only
+        """
+        dt1 = datetime.datetime(self.startyear, self.startmonth, self.startday,
+                                self.starthour, self.startmin, self.startsec)
+        dt2 = datetime.datetime(other.startyear, other.startmonth, other.startday,
+                                other.starthour, other.startmin, other.startsec)
+        return (dt1 > dt2)
+    
+    def __ge__(self, other):
+        """ __ge__ compares two MadrigalExperiment objects.
+
+        Compared by start time only
+        """
+        dt1 = datetime.datetime(self.startyear, self.startmonth, self.startday,
+                                self.starthour, self.startmin, self.startsec)
+        dt2 = datetime.datetime(other.startyear, other.startmonth, other.startday,
+                                other.starthour, other.startmin, other.startsec)
+        return (dt1 >= dt2)
+    
+    
+    
+    
 
 
 class MadrigalExperimentFile:
@@ -2418,7 +2518,7 @@ class MadrigalExperimentFile:
 
         expId - experiment id of the experiment this MadrigalExperimentFile belongs in
         
-        doi - digital object identifier - citable url to file
+        doi - digital object identifier - citable url to file - or None if not found
             
 
     Non-standard Python modules used: None
@@ -2484,21 +2584,23 @@ class MadrigalExperimentFile:
         else:
             self.expId = int(expId)
             
+        if not isStringType(doi) and not doi is None:
+            raise ValueError('In MadrigalExperimentFile, doi not string type or None: %s' % (str(doi)))
         self.doi = doi
             
         
 
     def __str__(self):
-        """return a readible form of this object"""
+        """return a readable form of this object"""
         retStr = ''
-        retStr += 'name: %s\n' % (str(self.name))
+        retStr += 'name: %s\n' % (self.name)
         retStr += 'kindat: %s\n' % (str(self.kindat))
-        retStr += 'kindatdesc: %s\n' % (str(self.kindatdesc))
+        retStr += 'kindatdesc: %s\n' % (self.kindatdesc)
         retStr += 'category: %s\n' % (str(self.category))
-        retStr += 'status: %s\n' % (str(self.status))
+        retStr += 'status: %s\n' % (self.status)
         retStr += 'permission: %s\n'%  (str(self.permission))
         retStr += 'expId: %s\n'%  (str(self.expId))
-        retStr += 'doi: %s\n'%  (str(self.doi))
+        retStr += 'doi: %s\n'%  (self.doi)
         return retStr
 
 
@@ -2596,12 +2698,12 @@ class MadrigalParameter:
     def __str__(self):
         """return a readible form of this object"""
         retStr = ''
-        retStr += 'mnemonic: %s\n' % (str(self.mnemonic))
-        retStr += 'description: %s\n' % (str(self.description))
+        retStr += 'mnemonic: %s\n' % (self.mnemonic)
+        retStr += 'description: %s\n' % (self.description)
         retStr += 'isError: %s\n' % (str(self.isError))
-        retStr += 'units: %s\n' % (str(self.units))
+        retStr += 'units: %s\n' % (self.units)
         retStr += 'isMeasured: %s\n' % (str(self.isMeasured))
-        retStr += 'category: %s\n'%  (str(self.category))
+        retStr += 'category: %s\n'%  (self.category)
         retStr += 'isSure: %s\n'%  (str(self.isSure))
         retStr += 'isAddIncrement: %s\n'%  (str(self.isAddIncrement))
         return retStr     
